@@ -49,6 +49,7 @@ int main (int argc, char** argv)
   //Initialize gnome-vfsmm:
   Gnome::Vfs::init();
  
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     Gnome::Vfs::DirectoryHandle handle;
@@ -68,6 +69,47 @@ int main (int argc, char** argv)
   /* if the operation was not successful, print the error and abort */
     return print_error(ex, input_uri_string);
   }
+#else
+  std::auto_ptr<Gnome::Vfs::exception> error;
+
+  Gnome::Vfs::DirectoryHandle handle;
+  printf ("Open()...\n");
+  fflush (stdout);
+  handle.open(input_uri_string,
+              Gnome::Vfs::FILE_INFO_DEFAULT | 
+                  Gnome::Vfs::FILE_INFO_GET_MIME_TYPE |
+                  Gnome::Vfs::FILE_INFO_FORCE_SLOW_MIME_TYPE,
+              error);
+  printf ("Handle opened\n");
+  fflush (stdout);
+
+  if(error.get())
+  {
+    printf ("Error set from open()\n");
+    fflush (stdout);
+    /* if the operation was not successful, print the error and abort */
+    return print_error(*error.get(), input_uri_string);
+  }
+  else
+  {
+    printf ("Error not set from open()\n");
+    fflush (stdout);
+  }
+
+  bool file_exists = true;
+  while(file_exists) //read_next() returns false when there are no more files to read.
+  {
+    Glib::RefPtr<Gnome::Vfs::FileInfo> refFileInfo = handle.read_next(file_exists, error);
+
+    if(error.get())
+    {
+      /* if the operation was not successful, print the error and abort */
+      return print_error(*error.get(), input_uri_string);
+    }
+
+    std::cout << refFileInfo->get_name() << ",    MIME-type: " << refFileInfo->get_mime_type() << std::endl;
+  }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
   
  
   return 0;
