@@ -1,4 +1,4 @@
-/* Copyright 2003 gnome-vfsmm Development Team
+/* Copyright 2003, 2006 gnome-vfsmm Development Team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -244,12 +244,34 @@ void remove(const Glib::RefPtr<const Uri>& source_uri,
   #endif
 }
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 void remove_list(const Glib::StringArrayHandle& source_uri_list,
       TransferOptions options,
       ErrorMode error_mode,
       const SlotProgress& slot)
+#else
+void remove_list(const Glib::StringArrayHandle& source_uri_list,
+      TransferOptions options,
+      ErrorMode error_mode,
+      const SlotProgress& slot,
+      std::auto_ptr<Gnome::Vfs::exception>& error)
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 {
-  //TODO:
+  std::list< Glib::RefPtr<const Uri> > list_uris;
+  
+  //Build lists of RefPtr<Uri>s from the strings:
+  Glib::StringArrayHandle::const_iterator it(source_uri_list.begin());
+  Glib::StringArrayHandle::const_iterator end(source_uri_list.end());
+  for( ; it != end; ++it)
+  {
+    list_uris.push_back(Uri::create(*it));
+  }
+  
+  #ifdef GLIBMM_EXCEPTIONS_ENABLED
+  remove_list_uris(list_uris, options, error_mode, slot);
+  #else
+  remove_list_uris(list_uris, options, error_mode, slot, error);
+  #endif
 }
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -278,7 +300,6 @@ void remove_list_uris(const ListHandleUris& source_uri_list,
   #endif //GLIBMM_EXCEPTIONS_ENABLED
 }
 
-
 } // namespace Transfer
 } // namespace Vfs
 } // namespace Gnome
